package PVE::LXC::Setup::ALTLinux;

use strict;
use warnings;
use Digest::SHA;
use Crypt::Eksblowfish::Bcrypt;
use PVE::LXC::Setup::Base;
use base qw(PVE::LXC::Setup::Base);

sub new {
       my ($class, $conf, $rootdir) = @_;
       my $ostype = "altlinux";
       my $version = PVE::Tools::file_read_firstline("$rootdir/etc/$ostype-release");
       my $self = { conf => $conf, rootdir => $rootdir, version => $version };
       $conf->{ostype} = $ostype;
       return bless $self, $class;
}

sub setup_init {
    my ($self, $conf) = @_;

    $self->fixup_old_getty();

    $self->setup_container_getty_service($conf);
}

sub setup_network {
    my ($self, $conf) = @_;
    $self->setup_systemd_networkd($conf);
}

sub template_fixup {
    my ($self, $conf) = @_;
    $self->setup_securetty($conf, qw(pts/0 console lxc/console lxc/tty1 lxc/tty2));
}

sub set_user_password {
    my ($self, $conf, $user, $opt_password) = @_;

    my $shadowfile = "/etc/tcb/$user/shadow";
    return if !$self->ct_file_exists($shadowfile);

    if (defined($opt_password)) {
       if ($opt_password !~ m/^\$/) {
           my $salt = Crypt::Eksblowfish::Bcrypt::en_base64(substr(Digest::SHA::sha1_base64(time), 0, 16));
           $opt_password = Crypt::Eksblowfish::Bcrypt::bcrypt($opt_password, '$2a$08$'.$salt);
       };
    } else {
       $opt_password = '*';
    }

    my $data = $user . ":" . $opt_password . ":" . (int(time()/86400)) . "::::::\n";

    my $st = $self->ct_stat($shadowfile) || die "unable to stat file - $!";
    $self->ct_file_set_contents($shadowfile, $data);
    chmod $st->mode, $shadowfile;
    chown $st->uid, $st->gid, $shadowfile;
}

1;
